class Hermes::Admin::ReservationHoldersController < Hermes::Admin::BaseController
  before_filter :authorize_users
  before_action :set_instance, only: [:edit, :update, :destroy, :show]
  before_action :check_adminrole
  rescue_from JSON::ParserError, with: :invalid_json

  def index
    @instances =  Hermes::ReservationHolder.readable_by(current_user)
      .paginate(:page => params[:page])
    respond_to do |format|
      format.html
      format.js
    end
  end

  def new
    @instance = Hermes::ReservationHolder.new
  end

  def edit; end

  def create
    @instance = Hermes::ReservationHolder.create(
      name: p_params[:name],
      siren: p_params[:siren],
      public_read: p_params[:public_read],
      lessor_ids: p_params[:lessor_ids],
      user_id: current_user.id
    )

    if @instance.save
      flash[:notice] = "Créé avec succès."
      redirect_to admin_reservation_holders_path
    else
      flash[:error] = @instance.errors.full_messages.to_sentence
      render :new
    end
  end

  def show; end

  def update
    @lessors = Hermes::Lessor.all.limit(10)

    @instance[:name] = p_params[:name]
    @instance[:siren] = p_params[:siren]
    @instance[:public_read] = p_params[:public_read]
    @instance[:lessor_ids] = p_params[:lessor_ids]

    if @instance.save
      flash[:notice] = "Mise à jour effectuée"
      redirect_to admin_reservation_holders_path
    else
      flash[:error] = @instance.errors.full_messages.to_sentence
      render :edit
    end
  end

  def destroy
    if @instance.destroy
      flash[:notice] = "Provider supprimé"
      redirect_to admin_reservation_holders_path
    else
      flash[:error] = @instance.errors.full_messages.to_sentence
      render :show
    end
  end

  private
  def invalid_json
    flash[:error] = "Invalid json for roles"
    render params[:action] == "update" ? :edit : :new
  end

  def set_instance
    @instance = Hermes::ReservationHolder.find(params[:id])
  end

  # def p_params
	# 	params.require(:reservation_holder).permit(
	# 		:name,
	# 		:siren,
  #     :public_read,
  #     :lessor_ids
	# 	)
	# end

  def p_params
    p_params = params[:reservation_holder]
    p_params[:siren] = p_params[:siren] - [""]
    p_params
  end
end 