# frozen_string_literal: true

class Hermes::Api::Dmo::HousingOfferExpirationSettingsController < Hermes::Api::Dmo::ApplicationController
  before_action :authorize_administrator!
  set_instance_for %i[index show create update destroy]

  VALID_OPERATORS = %w[$in $nin $ne $gt $gte $lt $lte $eq $regex $all]
  ACCEPTABLE_PARAMS = %w[
    ids
    created_at
    updated_at
    department
    max_applicants
    expiry_days
    minimal_publication_days
    lessor_id
  ]
  MUTATE_PARAMS = %i[
    department
    max_applicants
    expiry_days
    minimal_publication_days
    lessor_id
  ]
  
  def mutate_params
    MUTATE_PARAMS
  end 


  def index
    acceptable_params *ACCEPTABLE_PARAMS
    valid_operators *VALID_OPERATORS
    super
  end

  def authorize_administrator!
    return render_json_error(:unauthorized, :not_admin) unless current_user_roles.include?('Administrator')
  end
end
