# frozen_string_literal: true

class HousingRequestEntityUpdateJob < ActiveJob::Base
  queue_as :housing_request_entity_update
  unique :until_executed

  def perform(entity_id, siret_was, siren_was)
    e = Hermes::Entity.find(entity_id)

    old_housing_requests = find_housing_requests(siret_was, siren_was)
    new_housing_requests = find_housing_requests(e.siret, e.siren)

    update_housing_requests(old_housing_requests)
    update_housing_requests(new_housing_requests)
  end

  def update_housing_requests(housing_requests)
    housing_requests.each do |hr|
      hr.update_entity_relationship
      hr.save! if hr.changed?
    end 
  end 

  def find_housing_requests(siret, siren)
    applicant_ids = Hermes::Applicant.where(
      "$or": [
        {main_employer_siret: siret},
        {main_employer_siret: /^#{siren}/},
      ]
    ).pluck(:id)

    Hermes::HousingRequest.where(
      last_entity_code: nil,
      "$or": [
        {:applicant_used_for_siret.in => applicant_ids},
        {:main_applicant_id.in => applicant_ids, applicant_used_for_siret: nil},
      ]
    )
  end 
end
