# frozen_string_literal: true

module Hermes
  # Contact group class
  class ContactGroup
    include Hermes::Concerns::CommonFieldsConcern
    field :main_contact_id, type: BSON::ObjectId
    field :contact_ids, type: Array, default: []

    common_indexes *%i[
      main_contact_id
    ]

    belongs_to :entity, class_name: 'Hermes::Entity'
    belongs_to :lessor, class_name: 'Hermes::Lessor'

    writer_roles 'Superadmin', 'Administrator'
    reader_roles 'Manager'
    owner_field :user_id

    before_save :before_actions

    def contacts=(arr)
      self.contact_ids = arr.map do |doc|
        doc.id if doc.is_a?(::Doc) && doc.type == 'contact'
      end
    end

    def contacts
      ::Doc.where(:id.in => contact_ids)
    end

    def update_contacts
      ids = ::Doc.where(id: { :$in => contact_ids }, type: 'contact')
                 .pluck(:id).uniq.compact
      self.contact_ids = ids
    end

    def update_main_contact
      if ::Doc.find_by(id: main_contact_id).blank?
        self.main_contact_id = nil
      elsif !contact_ids.include?(main_contact_id)
        self.contact_ids = contact_ids << main_contact_id
      end
    end

    def before_actions
      update_contacts if contact_ids_changed?
      update_main_contact if main_contact_id_changed?
    end
  end
end
