# frozen_string_literal: true

# exemple d'utilisation
# so=Hermes::BoClient::AddRequestTask.new(
#  {'housing_offer_id' => '1234', 'applicant_id' => '2345'}
# )
# so.to_xml # pour voir le xml genere
# so.execute # pour lancer l'appel REST vers Hermes::BoClient.config

module Hermes
  module BoClient
    class OfferStatusTask < BaseTask
  
      def initialize(options = {})
        @xsd = 'StatutOffre.xsd'
        super(options)
      end
      
      endpoint {'/ws/rest/als/bien/v1/modifierStatut'}
      
      task_name 'offer_status_task'
      type_flux 'BIEN'
      mapping 'Hermes::BoClient::Mappings::HousingOfferMap'
      
      params *%i[
      refInterneDemande
      refInterneOffre
      ]
      
      def to_xml
        namespaces = {
            'xmlns:ns2' => 'http://v1.als.ikos.webservice.immobilier.sopra/bien/statutOffre'
        }
        builder = Nokogiri::XML::Builder.new(encoding: 'UTF-8') do |b|
          b['ns2'].statutOffre(namespaces) do
             
                 b.refInterneOffre mapping.reference_offre do
                   b.parent.namespace = nil
                 end
                 b.statut mapping.statut  do
                   b.parent.namespace = nil
                 end
             
          end
        end
        builder.to_xml
      end
    end
  end
end
