require 'rails_helper'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')

  describe Api::Dmo::AccountingsController, :type => :api do
    routes { Hermes::Engine.routes }
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper

    let!(:admin) { create :administrator, auth_roles: ['superadministrateur'] }

    describe 'GET index' do
      let!(:request1) { create :accounting, target: 'request', year: 2019 }
      let!(:request2) { create :accounting, target: 'request', year: 2020 }
      let!(:request3) { create :accounting, target: 'request', year: 2020 }
      let!(:offer1) { create :accounting, target: 'offer', year: 2020 }
      let!(:offer2) { create :accounting, target: 'offer', year: 2021 }

      before do
        authenticated_header(request, admin)
      end

      it 'returns a valid json' do
        get 'index'
        expect(response).to have_http_status 200
        expect(json['data'].count).to eq 5
        expect(json['meta']['pagination']['total_objects']).to eq 5
        expect(json['data'].map { |d| d['id'] }).to contain_exactly(request1.id, request2.id, request3.id, offer1.id, offer2.id)
      end

      it 'filters by target' do
        get 'index', target: 'offer'
        expect(response).to have_http_status 200
        expect(json['data'].count).to eq 2
        expect(json['data'].map { |d| d['id'] }).to contain_exactly(offer1.id, offer2.id)
      end

      it 'filters by year' do
        get 'index', year: 2020
        expect(response).to have_http_status 200
        expect(json['data'].count).to eq 3
        expect(json['data'].map { |d| d['id'] }).to contain_exactly(request2.id, request3.id, offer1.id)
      end
    end
  end
end